From 2965a981b7ec22866fbdf2d567d87e2d068d3617 Mon Sep 17 00:00:00 2001
From: Thomas Bruederli <thomas@roundcube.net>
Date: Fri, 31 Jul 2015 16:04:08 -0400
Subject: [PATCH] Allow to search and import missing PGP pubkeys from keyservers using Publickey.js
---
program/lib/Roundcube/rcube_storage.php | 29 +++++++++++++++++++++++------
1 files changed, 23 insertions(+), 6 deletions(-)
diff --git a/program/lib/Roundcube/rcube_storage.php b/program/lib/Roundcube/rcube_storage.php
index 69d6d2f..23e6577 100644
--- a/program/lib/Roundcube/rcube_storage.php
+++ b/program/lib/Roundcube/rcube_storage.php
@@ -152,6 +152,19 @@
/**
+ * Get connection/class option
+ *
+ * @param string $name Option name
+ *
+ * @param mixed Option value
+ */
+ public function get_option($name)
+ {
+ return $this->options[$name];
+ }
+
+
+ /**
* Activate/deactivate debug mode.
*
* @param boolean $dbg True if conversation with the server should be logged
@@ -479,22 +492,24 @@
/**
* Returns the whole message source as string (or saves to a file)
*
* @param int $uid Message UID
* @param resource $fp File pointer to save the message
*
* @return string Message source string
*/
- abstract function get_raw_body($uid, $fp = null);
+ abstract function get_raw_body($uid, $fp = null, $part = null);
/**
* Returns the message headers as string
*
* @param int $uid Message UID
*
* @return string Message headers string
*/
- abstract function get_raw_headers($uid);
+ abstract function get_raw_headers($uid, $part = null);
/**
@@ -905,9 +920,11 @@
/**
* Get mailbox quota information.
*
+ * @param string $folder Folder name
+ *
* @return mixed Quota info or False if not supported
*/
- abstract function get_quota();
+ abstract function get_quota($folder = null);
/* -----------------------------------------
@@ -479,22 +492,24 @@
* Returns the whole message source as string (or saves to a file)
*
- * @param int $uid Message UID
- * @param resource $fp File pointer to save the message
+ * @param int $uid Message UID
+ * @param resource $fp File pointer to save the message
+ * @param string $part Optional message part ID
*
* @return string Message source string
@@ -479,22 +492,24 @@
* Returns the message headers as string
*
- * @param int $uid Message UID
+ * @param int $uid Message UID
+ * @param string $part Optional message part ID
*
* @return string Message headers string
--
Gitblit v1.9.1